@@ -178,7 +178,7 @@ class VerifyToken:
                     self.mongo_user),
                 status=500,
             )
-        permission_list = [0]
+        permission_list = []
         is_all_data = False
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
@@ -192,7 +192,7 @@ class VerifyToken:
             if roles:
                 permission_list = roles[0]['permission_status']  # list类型
                 is_all_data = roles[0]['is_all_data']  # 是否开放全部数据
-        if [0] == permission_list:
+        if ([0] == permission_list) or (not permission_list):
             handle_abnormal(
                 message='无 "{0}-{1}" 的访问权限({2})'.format(
                     center_name, permission_name, str(permission_list)),
